@@ -41,10 +41,16 @@
 #include <fcntl.h>
 #include <unistd.h>
 
+#ifdef HAVE_BYTESWAP_H
 #include <byteswap.h>
-
 #define BMPSwabShort(x) *x = bswap_16 (*x)
 #define BMPSwabLong(x) *x = bswap_32 (*x)
+#else
+#define BMPSwabShort(x) *x = ((((*x) >> 8) & 0xffu) | (((*x) & 0xffu) << 8))
+#define BMPSwabLong(x) *x = \
+     ((((*x) & 0xff000000u) >> 24) | (((*x) & 0x00ff0000u) >>  8) |	\
+      (((*x) & 0x0000ff00u) <<  8) | (((*x) & 0x000000ffu) << 24))
+#endif
 
 #include <inttypes.h>
 
