@@ -19,7 +19,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: ght_hash_table.h.in,v 1.1 2004/03/11 06:20:29 steinm Exp $
+ * $Id: ght_hash_table.h.in,v 1.2 2007/06/23 20:47:15 steinm Exp $
  *
  ********************************************************************/
 
@@ -79,7 +79,8 @@ extern "C" {
 #endif
 
 /** unsigned 32 bit integer. */
-typedef unsigned int ght_uint32_t;
+/*typedef unsigned  _ght_uint32_t;*/
+typedef u_int32_t ght_uint32_t;
 
 /**
  * The structure for hash keys. You should not care about this
