@@ -445,7 +445,7 @@ void ps_del_resources(PSDoc *psdoc);
 void ps_del_parameters(PSDoc *psdoc);
 void ps_del_values(PSDoc *psdoc);
 void ps_del_bookmarks(PSDoc *psdoc, DLIST *bookmarks);
-int ps_check_for_lig(ADOBEFONTMETRIC *metrics, ADOBEINFO *ai, const char *text, char ligdischar, char **newadobename, int *offset);
+int ps_check_for_lig(PSDoc *psdoc, ADOBEFONTMETRIC *metrics, ADOBEINFO *ai, const char *text, char ligdischar, char **newadobename, int *offset);
 ght_hash_table_t *ps_build_enc_hash(PSDoc *psdoc, ENCODING *enc);
 ght_hash_table_t *ps_build_enc_from_font(PSDoc *psdoc, ADOBEFONTMETRIC *metrics);
 ENCODING *ps_build_enc_vector(PSDoc *psdoc, ght_hash_table_t *hashvec);
