@@ -18,7 +18,7 @@
  *    Boston, MA 02111-1307, USA.
  */
 
-/* $Id: ps_util.c,v 1.36 2005/06/20 11:34:04 steinm Exp $ */
+/* $Id: ps_util.c,v 1.39 2007/04/16 14:40:18 steinm Exp $ */
 
 #include <stdio.h>
 #include <errno.h>
@@ -314,7 +314,7 @@ float ps_get_word_spacing(PSDoc *psdoc, PSFont *psfont) {
  * and offset is set to 1 in order to skip the ligdischar. newadobename is set
  * to the name of the passed character.
  */
-int ps_check_for_lig(ADOBEFONTMETRIC *metrics, ADOBEINFO *ai, const char *text, char ligdischar, char **newadobename, int *offset) {
+int ps_check_for_lig(PSDoc *psdoc, ADOBEFONTMETRIC *metrics, ADOBEINFO *ai, const char *text, char ligdischar, char **newadobename, int *offset) {
 	ADOBEINFO *nextai;
 	LIG *ligs;
 	if((NULL == ai) || (NULL == ai->ligs))
@@ -335,7 +335,7 @@ int ps_check_for_lig(ADOBEFONTMETRIC *metrics, ADOBEINFO *ai, const char *text,
 	if(ligs) {
 		int _offset = 0;
 		char *nextadobename;
-		nextai = gfindadobe(metrics->gadobechars, inputencoding.vec[(unsigned char) (text[0])]);
+		nextai = gfindadobe(metrics->gadobechars, psdoc->inputenc->vec[(unsigned char) (text[0])]);
 		if(NULL == nextai)
 			return 0;
 
@@ -344,7 +344,7 @@ int ps_check_for_lig(ADOBEFONTMETRIC *metrics, ADOBEINFO *ai, const char *text,
 		 * ligature. First check if current char and ligature of 2nd and 3th
 		 * char for a ligature.
 		 */
-		if(ps_check_for_lig(metrics, nextai, &text[1], ligdischar, &nextadobename, &_offset)) {
+		if(ps_check_for_lig(psdoc, metrics, nextai, &text[1], ligdischar, &nextadobename, &_offset)) {
 			while(ligs) {
 				if(0 == strcmp(ligs->succ, nextadobename)) {
 					*offset += 1+_offset;
@@ -369,7 +369,7 @@ int ps_check_for_lig(ADOBEFONTMETRIC *metrics, ADOBEINFO *ai, const char *text,
 				 */
 				ligai = gfindadobe(metrics->gadobechars, ligs->sub);
 				if(ligai) {
-					if(ps_check_for_lig(metrics, ligai, &text[1], ligdischar, &nextadobename, offset)) {
+					if(ps_check_for_lig(psdoc, metrics, ligai, &text[1], ligdischar, &nextadobename, offset)) {
 						*newadobename = nextadobename;
 						return 1;
 
@@ -561,7 +561,7 @@ FILE *ps_open_file_in_path(PSDoc *psdoc, const char *filename) {
 		return fp;
 
 	if(NULL != (pathres = ps_get_resources(psdoc, "SearchPath", &count))) {
-		for(i=count-1; i>0; i--) {
+		for(i=count-1; i>=0; i--) {
 			snprintf(buffer, 255, "%s/%s", pathres[i]->value, filename);
 			fprintf(stderr, "Searching for %s\n", buffer);
 			if(fp = fopen(buffer, "r")) {
@@ -606,9 +606,9 @@ int ps_ascii85_encode(PSDoc *psdoc, char *data, size_t len) {
 			cc++;
 		} else {
 			for(i=4; i>=0; i--) {
-				c = buffer / pow85[i];
+				c = (unsigned int) buffer / pow85[i];
 				ps_putc(psdoc, c+'!');
-				buffer = buffer % pow85[i];
+				buffer = (unsigned int) buffer % pow85[i];
 			}
 			cc += 4;
 		}
@@ -624,9 +624,9 @@ int ps_ascii85_encode(PSDoc *psdoc, char *data, size_t len) {
 			buffer = (buffer << 8) + (long) data[count+i];
 		buffer = buffer << ((4-len+count)*8);
 		for(i=4; i>=4-len+count; i--) {
-			c = buffer / pow85[i];
+			c = (unsigned int) buffer / pow85[i];
 			ps_putc(psdoc, c+'!');
-			buffer = buffer % pow85[i];
+			buffer = (unsigned int) buffer % pow85[i];
 		}
 	}
 	ps_putc(psdoc, '~');
@@ -638,7 +638,7 @@ int ps_ascii85_encode(PSDoc *psdoc, char *data, size_t len) {
  */
 int ps_asciihex_encode(PSDoc *psdoc, char *data, size_t len) {
 	int i, cc=0;
-	char *dataptr;
+	unsigned char *dataptr;
 
 	dataptr = data;
 	for(i=0; i<len; i++) {
